#pragma once
#ifndef S_SIF1_DEC_LIB
#define S_SIF1_DEC_LIB

#ifdef __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include "VersionN.h"

	typedef void* SIF_DEC_HANDLE;

	typedef enum OutputFormat {
		OF_RGB_24 = 1,
		OF_RGB_32 = 2,
		OF_YUY2 = 3,
		OF_UYVY = 4,
		OF_YV12 = 5,
		OF_I420 = 6,
		OF_NV12 = 7,
		OF_P010 = 8,
		OF_P010 = 8,
		OF_I420p10 = 9,
		OF_I420p16 = 10,
	} OutputFormat;

	typedef struct SifDecSetting {
		OutputFormat frm;
		int32_t x, y; // Image size
		int32_t tr_num; // Number of supported parallel threads
		int32_t flip_outp; // Vertical image size. If negative then vertical flip
		int32_t pitch_x;
		OptimizationMode cpu;
		int32_t ref_fr_n; //number of used references frames
	} SifDecSetting;

	typedef struct SifDecFramreInfo {
		int32_t profile; // 2
		int32_t skip_m;  //1
		int32_t skip_index; //3
		S_ReferenceMode set_ref;  //2
		int32_t key_fr; //1  
		int32_t intra_m; // 1
		int32_t reset_st; // 1 // Total 8 bits 1 byte
		/////////////////
		int32_t fr_size; // frame size
		/////////////
		int32_t x; // image size
		int32_t y; // image size
		int32_t fr_rate; // Frame frequency nominator 
		int32_t fr_scale; // Frame frequency denominator
		int32_t AspectRatioX;  // Aspect ratio nominator // max 8 bit // 0 - Off
		int32_t AspectRatioY;  // Aspect ratio denominator
		int32_t field_ord; // Fields order 0 -Top field first, 1-Bottom field first.
		EntropyMode ari_tr; // 3
		CollorSpaceMode colSp; // 3
		CollorResolution colRes; //2 // only 420 support
		PixelPrecision bit_Dep; //2  // 8,10,12 bit support.
		int32_t interlace_m; // Source with interleaving // 0 - Off out of usage
		int32_t set_framerate; //1
		int32_t set_aspect_ratio; //1
		int32_t set_num_ref_f; //1  // Total 16 bits - 2 bytes
		int32_t ref_fr_n; // Number of reference frames
		VideoTransferFunction colVTS; // Additional parameters of the video transfer function
		VideoPrimaries colVP; // Additional parameters of the source
		NominalRange colNR; // Additional field for render range
	}SifDecFramreInfo;


	DLL_EXPORT_IMPORT(size_t, SD_DLL_GetH_Size)();

	DLL_EXPORT_IMPORT(SIF_DEC_HANDLE, SD_DLL_InitS_Handle)(uint8_t* h_data, SifDecSetting* dec_set);

	DLL_EXPORT_IMPORT(size_t, SD_DLL_GetCurMemSize)(SIF_DEC_HANDLE sdh, SifDecSetting* dec_set);

	DLL_EXPORT_IMPORT(uint32_t, SD_DLL_InitMemData)(SIF_DEC_HANDLE sdh, uint8_t* s_data);

	DLL_EXPORT_IMPORT(void, SD_DLL_SetOutputFormat)(SIF_DEC_HANDLE sdh, OutputFormat of);

	DLL_EXPORT_IMPORT(void, SD_DLL_SetOutputPitch)(SIF_DEC_HANDLE sdh, int32_t pitch_x, int32_t pitch_y);

	DLL_EXPORT_IMPORT(int32_t, SD_DLL_ProcessDecFrame)(SIF_DEC_HANDLE sdh, uint8_t* in_data, int32_t reserved, int32_t pitch, uint8_t* out_data);

	DLL_EXPORT_IMPORT(void, SD_DLL_StopDecoder)(SIF_DEC_HANDLE sdh);

	DLL_EXPORT_IMPORT(void, SD_DLL_GetCurSettings)(SIF_DEC_HANDLE sdh, SifDecSetting* dec_set);

	DLL_EXPORT_IMPORT(int32_t, SD_DLL_ParseSifHeader)(uint8_t* in_data, SifDecFramreInfo* frame_data); // Return 0 - error, 1 - skip fr, 2- delta fr, 3- key fr

	DLL_EXPORT_IMPORT(int32_t, SD_DLL_GetVersionN)();
#ifdef __cplusplus
}
#endif

#endif //S_SIF1_DEC_LIB
